angular.module('wsmob.directives', [])
.directive('weightConversion', [function () {
/* --------------------------------------------  
 | Directive converts weigth between model and view (two way binding)
 | based on supplied units attribute
 */          
  return {
    require: 'ngModel',
    link: function (scope, elem, attrs, ngModel) {           
         console.log(attrs);
      // convert value for view   
      var toView = function (val) {
        if(val !== ''){
             console.log('weightConversion', attrs.units);
              if( attrs.units === 'kg/cm'){
                return val/2.20462;  
              }else if(attrs.units === 'lb/in'){
                return val;   
              }       
        }  
      }; 
      // convert value for model
      var toModel = function (val) {
           console.log('weightConversion', attrs.units);      
          if( attrs.units === 'kg/cm'){
            return val*2.20462;  
          }else if(attrs.units === 'lb/in'){
            return val;   
          } 
      };
      // set formatter / parsers
      ngModel.$formatters.unshift(toView);
      ngModel.$parsers.unshift(toModel);
    }
  };
}]
)
.directive('lengthConversion', [function () {
 /* --------------------------------------------  
 | Directive converts length between model and view (two way binding)
 | based on supplied units attribute
 */  
  return {
    require: 'ngModel',
    link: function (scope, elem, attrs, ngModel) {  
            console.log(attrs);          
            // convert value for view
            var toView = function (val) {
              if(val !== ''){        
                  console.log('lengthConversion', attrs.units);
                    if(attrs.units === 'kg/cm'){
                      return val*2.54; 
                    }else if(attrs.units === 'lb/in'){
                      return val;   
                    }         
              }  
            };
            // convert value for model
            var toModel = function (val) {   
                console.log('lengthConversion', attrs.units);
                if(attrs.units === 'kg/cm'){
                  return val/2.54;  
                }else if(attrs.units === 'lb/in'){
                  return val;   
                } 
            };    
            // set formatter / parsers
            ngModel.$formatters.unshift(toView);
            ngModel.$parsers.unshift(toModel);                       
    }
  };
}]
)
.directive('lengthConversionDynamic', [function () {
/* --------------------------------------------  
 | Directive converts weight between model and view (two way binding)
 | based on supplied units attribute - also watches view variable
 | to dynamically update view based on setting changes.        
 */          
 return {
    require: 'ngModel',
    link: function (scope, elem, attrs, ngModel) { 
            console.log(attrs);          
            // convert value for view
            var toView = function (val) {
              if(val !== ''){            
                  console.log('lengthConversion', attrs.units);
                    if(attrs.units === 'kg/cm'){
                      return val*2.54; 
                    }else if(attrs.units === 'lb/in'){
                      return val;   
                    }         
              }  
            };
            // convert value for model
            var toModel = function (val) {   
                console.log('lengthConversion', attrs.units);
                if(attrs.units === 'kg/cm'){
                  return val/2.54;  
                }else if(attrs.units === 'lb/in'){
                  return val;   
                } 
            };    
            // set formatter / parsers
            ngModel.$formatters.unshift(toView);
            ngModel.$parsers.unshift(toModel); 
            
            // watch setting units and update model / view values accordingly
            scope.$watch('settings.units', function (newValue, oldValue) {
                    console.log("I see a data change!" + oldValue + " - " + newValue);
                    console.log(ngModel);
                    if(oldValue !== newValue){
                        console.log('lengthConversion units changed');
                        console.log(ngModel.$viewValue);
                        console.log(ngModel.$modelValue);
                        if(attrs.units === 'kg/cm'){
                            ngModel.$setViewValue((ngModel.$viewValue*2.54).toFixed(1));
                        }else if(attrs.units === 'lb/in'){
                            ngModel.$setViewValue((ngModel.$viewValue/2.54).toFixed(1));
                        } 
                        console.log(ngModel.$viewValue);
                        console.log(ngModel.$modelValue);
                        
                    }else{
                        console.log('lengthConversion units not changed');
                        if(attrs.units === 'kg/cm'){
                            ngModel.$setViewValue((ngModel.$modelValue*2.54).toFixed(1));
                        }else if(attrs.units === 'lb/in'){
                            ngModel.$setViewValue(parseFloat(ngModel.$modelValue).toFixed(1));
                        }                         
                    }
                    ngModel.$render();
            });
    }
  };
}]
)
.directive('numberConverter', function() {
/* --------------------------------------------  
 | Directive converts value between number and string
 */      
  return {
    priority: 1,
    restrict: 'A',
    require: 'ngModel',
    link: function(scope, element, attr, ngModel) {
      // convert value for model  
      function toModel(value) {
        console.log('number TM:', parseFloat(value));
        return parseFloat(value);//"" + value; // convert to string
      }
      // convert value for view
      function toView(value) {
        console.log('number TV:', parseFloat(value));
        return parseFloat(value); // convert to number
      }
      // set formatter / parsers
      ngModel.$formatters.push(toView);
      ngModel.$parsers.push(toModel);
    }
  };
})
.directive('dateConverter', function($filter) {
 /* --------------------------------------------  
 | Directive converts value between date object and string
 */     
  return {
    priority: 1,
    restrict: 'A',
    require: 'ngModel',
    link: function(scope, element, attr, ngModel) {
      // convert value for model  
      function toModel(value) {
        //console.log('date TM:'+value);
        //return "" + value; // convert to string
        var date = new Date(value);
        console.log('date TM:'+$filter('date')(date, "yyyy-MM-dd"));
        return $filter('date')(date, "yyyy-MM-dd");
      }
      // convert value for view
      function toView(value) {
        //console.log('date TV:'+value);
        //return $filter('date')(new Date(value), "yyyy-MM-dd");
        //return new Date(value); // convert to date
        var date = Date.parseExact(value,'yyyy-MM-dd');
        return date;
      }
      // set formatter / parsers
      ngModel.$formatters.push(toView);
      ngModel.$parsers.push(toModel);
    }
  };
    /*
 .directive('dateConverter', function($filter) {
  return {
      require: 'ngModel',
      link: function(scope, element, attrs, ngModelController) {
           ngModelController.$parsers.push(function(data) {
              //View -> Model
              var date = Date.parseExact(data,'yyyy-MM-dd');

              // if the date field is not a valid date 
              // then set a 'date' error flag by calling $setValidity
              ngModelController.$setValidity('date', date!=null);
              return date == null ? undefined : date;
           });
           ngModelController.$formatters.push(function(data) {
              //Model -> View
              val = new Date(data)
              return $filter('date')(val, "yyyy-MM-dd");
           });    
       }
   };   */
});

